@@ -19,8 +19,7 @@ from qctrl.utils import abstract_property
 
 
 class BaseHandler(ABC):  # pylint:disable=too-few-public-methods
-    """Base class for a GraphQL type handler.
-    """
+    """Base class for a GraphQL type handler."""
 
     _field_type = None
 
@@ -31,10 +30,14 @@ class BaseHandler(ABC):  # pylint:disable=too-few-public-methods
     def field_type(self):  # pylint:disable=missing-function-docstring
         return self._field_type
 
-    def _is_expected_type(self, field_type: GraphQLType,) -> bool:
+    def _is_expected_type(
+        self,
+        field_type: GraphQLType,
+    ) -> bool:
         """Checks if the given field type is of
         the expected type.
         """
         return isinstance(  # pylint:disable=isinstance-second-argument-not-valid-type
-            field_type, self.field_type,
+            field_type,
+            self.field_type,
         )
