@@ -140,8 +140,7 @@ class DataMixin(BaseHandlerMixin):
 
     @abstractmethod
     def _load_data(self, field_type: GraphQLType, data: Dict[str, Any]) -> Any:
-        """Private method to be overridden for loading the data.
-        """
+        """Private method to be overridden for loading the data."""
         raise NotImplementedError
 
     @staticmethod
@@ -171,8 +170,7 @@ class DataMixin(BaseHandlerMixin):
 
 
 class ScalarMixin(PayloadMixin, SelectionMixin, DataMixin):
-    """Handler mixin for all GraphQLScalar types.
-    """
+    """Handler mixin for all GraphQLScalar types."""
 
     _field_type = GraphQLScalarType
     _scalar_name = None
@@ -207,8 +205,7 @@ class ScalarMixin(PayloadMixin, SelectionMixin, DataMixin):
         )
 
     def _check_type(self, data: Any) -> bool:
-        """Checks that the data type is expected.
-        """
+        """Checks that the data type is expected."""
         allowed = self.scalar_allowed_type
 
         if not isinstance(allowed, list):
