@@ -51,3 +51,12 @@ class StringScalarHandler(ScalarMixin, BaseHandler):
     _scalar_encoder = json.dumps
     _scalar_allowed_type = str
     scalar_type_hint = str
+
+
+class IDScalarHandler(ScalarMixin, BaseHandler):
+    """Handler for GraphQL ID scalar type."""
+
+    _scalar_name = "ID"
+    _scalar_encoder = json.dumps
+    _scalar_allowed_type = str
+    scalar_type_hint = str
