@@ -37,8 +37,8 @@ from .builders import (
 )
 from .constants import DEFAULT_API_ROOT
 from .queries import (
-    ActivityMonitor,
-    GetResult,
+    ActivityMonitorQuery,
+    GetResultQuery,
 )
 from .utils import _check_qctrl_latest_version
 
@@ -188,15 +188,16 @@ class Qctrl:
             instead of returning a query. It will print out the formatted query result.
         """
 
-        query = ActivityMonitor(
-            self.gql_api,
-            self.gql_env,
-            limit=limit,
-            offset=offset,
-            status=status,
-            action_type=action_type,
+        query = ActivityMonitorQuery(self.gql_api)
+
+        return print(
+            query(
+                limit=limit,
+                offset=offset,
+                status=status,
+                action_type=action_type,
+            )
         )
-        return print(query())
 
     def get_result(self, action_id: str) -> "qctrl.dynamic.types.CoreActionResult":
         """This function is used to return the results of a previously run function.
@@ -212,8 +213,8 @@ class Qctrl:
         qctrl.dynamic.types.CoreActionResult
             an instance of a class derived from a CoreActionResult.
         """
-        get_result = GetResult(self.gql_api, self.gql_env, action_id=action_id)
-        return get_result()
+        get_result = GetResultQuery(self.gql_api)
+        return get_result(self.gql_env, action_id)
 
     def _run_gql_query(self, query: str, variable_values: Dict = None) -> Dict:
         """
