@@ -11,9 +11,12 @@
 # distributed under the License is distributed on an "AS IS" BASIS. See the
 # License for the specific language.
 # pylint:disable=missing-module-docstring
-from .activity_monitor import ActivityMonitor
+from .activity_monitor import ActivityMonitorQuery
 from .create_token import CreateTokenQuery
-from .get_environment import GetWorkerInfo
-from .get_result import GetResult
+from .get_environment import (
+    GetQueueInfoQuery,
+    GetWorkerInfoQuery,
+)
+from .get_result import GetResultQuery
 from .me import MeQuery
 from .refresh_token import RefreshTokenQuery
