@@ -14,9 +14,8 @@
 import logging
 from typing import Union
 
-from gql import Client
+from gql import gql
 from graphql import GraphQLType
-from qctrlcommons.exceptions import QctrlGqlException
 
 from qctrl.builders.custom_environment import QctrlGraphQLEnvironment
 
@@ -25,28 +24,46 @@ from .base import BaseQuery
 LOGGER = logging.getLogger(__name__)
 
 
-class GetResult(BaseQuery):  # pylint:disable=too-few-public-methods
+class GetResultQuery(BaseQuery):
     """This class is used to retrieve the results of a previously run `function`.
     If the function is still running it will wait until it's finished
     before returning the results."""
 
-    def __init__(
-        self, client: Client, env: QctrlGraphQLEnvironment, action_id: Union[str, int]
-    ):
+    def __call__(
+        self, env: QctrlGraphQLEnvironment, action_id: Union[str, int]
+    ):  # pylint:disable=arguments-differ
+        get_mutation_name_query = gql(
+            """
+            query getMutationName($modelId: String!) {
+                action(modelId: $modelId) {
+                    action {
+                        ... on CoreAction {
+                            mutationName
+                        }
+                    }
+                    errors {
+                        message
+                    }
+                }
+            }
         """
-        Parameters
-        ----------
-        client: Client
-            the graphql client
-        env: QctrlGraphQLEnvironment
-            the GraphQL environment object
-        action_id: str
-            the id an existing action
-        """
-        super().__init__(client, env)
-        self._action_id = action_id
+        )
 
-    def get_mutation_result_type(self, mutation_name: str) -> GraphQLType:
+        response = self._execute(get_mutation_name_query, {"modelId": str(action_id)})
+        self._handle_errors(get_mutation_name_query, response)
+
+        mutation_name = response["action"]["action"].get("mutationName")
+        field_type = self._get_mutation_result_type(mutation_name)
+
+        refresh_query = env.build_refresh_query(field_type, action_id)
+        response = self._execute(refresh_query)
+        self._handle_errors(refresh_query, response)
+
+        result = env.load_data(field_type, response["coreAction"]["coreAction"])
+        env.wait_for_completion(field_type, result, refresh_query)
+        return result
+
+    def _get_mutation_result_type(self, mutation_name: str) -> GraphQLType:
         """Returns the GraphQLType for the given mutation.
 
         Parameters
@@ -74,50 +91,3 @@ class GetResult(BaseQuery):  # pylint:disable=too-few-public-methods
             raise KeyError(f"unknown mutation: {mutation_name}") from error
 
         return mutation_field.type
-
-    def __call__(self) -> "qctrl.dynamic.types.CoreActionResult":
-        """Executes a query and returns an instance of a CoreActionResult derived class.
-
-        Returns
-        -------
-        CoreActionResult
-            an instance of a `CoreActionResult` derived class.
-
-        Raises
-        ------
-        QctrlGqlException
-            if there's something wrong happen.
-        """
-
-        query = (
-            """
-            query {
-                action(modelId: "%s") {
-                    action {
-                        ... on CoreAction {
-                            mutationName
-                        }
-                    }
-                    errors {
-                        message
-                    }
-                }
-            }
-        """
-            % self._action_id
-        )
-        LOGGER.debug("query: %s", query)
-
-        response = self.execute_query(query)
-        if response["action"].get("errors"):
-            raise QctrlGqlException(
-                response["action"].get("errors"), format_to_snake=True
-            )
-        mutation_name = response["action"]["action"].get("mutationName")
-        field_type = self.get_mutation_result_type(mutation_name)
-
-        refresh_query = self._env.build_refresh_query(field_type, self._action_id)
-        response = self.execute_query(refresh_query)
-        result = self._env.load_data(field_type, response["coreAction"]["coreAction"])
-        self._env.wait_for_completion(field_type, result, refresh_query)
-        return result
