@@ -29,7 +29,6 @@ from qctrlcommons.auth import BearerTokenAuth
 from qctrlcommons.exceptions import QctrlException
 
 from qctrl import __version__
-from qctrl.builders import create_environment
 from qctrl.builders.client_builder import (
     create_client_auth,
     create_gql_client,
@@ -37,13 +36,13 @@ from qctrl.builders.client_builder import (
 )
 from qctrl.constants import DEFAULT_API_ROOT
 from qctrl.queries import (
-    ActivityMonitor,
+    ActivityMonitorQuery,
     CreateTokenQuery,
-    GetWorkerInfo,
+    GetQueueInfoQuery,
+    GetWorkerInfoQuery,
     RefreshTokenQuery,
 )
 from qctrl.queries.action_export import ActionExportQuery
-from qctrl.queries.get_environment import GetQueueInfo
 from qctrl.scripts_utils import (
     _process_output,
     _write_action_result_to_csv,
@@ -203,16 +202,8 @@ def activity(
     """
     # Attempts to use previously store auth file, prompts interactive auth otherwise.
     gql_api = create_gql_client(api_root, create_client_auth(api_root))
-    gql_env = create_environment(gql_api)
 
-    activity_monitor = ActivityMonitor(
-        gql_api,
-        gql_env,
-        limit=limit,
-        offset=offset,
-        status=status,
-        action_type=type,
-    )
+    activity_monitor = ActivityMonitorQuery(gql_api)
 
     if options:
         click.secho(
@@ -220,16 +211,19 @@ def activity(
         )
         if options == "status":
             [  # pylint: disable=expression-not-assigned
-                click.secho(value)
-                for value in activity_monitor.get_enum_values("ActionStatusEnum")
+                click.secho(value) for value in activity_monitor.get_valid_statuses()
             ]
         if options == "type":
             [  # pylint: disable=expression-not-assigned
-                click.secho(value)
-                for value in activity_monitor.get_enum_values("ActionTypeEnum")
+                click.secho(value) for value in activity_monitor.get_valid_types()
             ]
     else:
-        click.secho(activity_monitor())
+
+        click.secho(
+            activity_monitor(
+                limit=limit, offset=offset, status=status, action_type=type
+            )
+        )
 
 
 @main.command(help="Displays the current version of the 'qctrl' package.")
@@ -259,13 +253,12 @@ def env(api_root, type):  # pylint:disable=redefined-builtin
     environment.
     """
     gql_api = create_gql_client(api_root, create_client_auth(api_root))
-    gql_env = create_environment(gql_api)
     if type and type == "worker":
         # display per-worker view
-        get_env = GetWorkerInfo(gql_api, gql_env)
+        get_env = GetWorkerInfoQuery(gql_api)
     else:
         # display per-queue view
-        get_env = GetQueueInfo(gql_api, gql_env)
+        get_env = GetQueueInfoQuery(gql_api)
     print("Fetching environment details. Please wait ...")
     click.secho(get_env())
 
@@ -354,17 +347,14 @@ def action_export(api_root, start_date, end_date, ignore_test_users, file_name,
         click.echo(f"Cannot find Path {directory_path}")
     else:
         gql_api = create_gql_client(api_root, create_client_auth(api_root))
-        gql_env = create_environment(gql_api)
-        action_export_query = ActionExportQuery(
-            gql_api, gql_env, start_date, end_date, ignore_test_users
-        )
-        action_result = action_export_query()
+        action_export_query = ActionExportQuery(gql_api)
+        result = action_export_query(start_date, end_date, ignore_test_users)
 
-        if not action_result:
+        if not result:
             click.echo("No match action data found")
         else:
             # format and save the result to file
             saved_path = directory_path / file_name
-            _write_action_result_to_csv(saved_path, action_result)
+            _write_action_result_to_csv(saved_path, result)
 
             click.echo(f"The result has been saved to {saved_path}")
