@@ -11,12 +11,15 @@
 # distributed under the License is distributed on an "AS IS" BASIS. See the
 # License for the specific language.
 # pylint:disable=missing-module-docstring
+import csv
 import hashlib
 import json
 import logging
 from pathlib import Path
 from typing import (
     Callable,
+    Dict,
+    List,
     Tuple,
 )
 
@@ -151,3 +154,43 @@ def interactive_authentication(
     except (exceptions.ConnectionError, exceptions.MissingSchema) as exc:
         LOGGER.error("%s", exc, exc_info=True)
         raise QctrlException(f"{api_root} is not a valid Q-CTRL URL.") from exc
+
+
+def _write_action_result_to_csv(path: str, actions: List):
+    """
+    Covert action result to csv format
+
+    Parameters
+    ----------
+    path: str
+        Saved file path. It requires filename and file path (i.e path/filename.csv).
+    actions: List
+        List of action data.
+    """
+    with open(path, "w") as file:
+        writer = csv.DictWriter(file, fieldnames=actions[0].keys())
+        writer.writeheader()
+        for json_dict_result in actions:
+            json_dict_result["user"] = json_dict_result["user"]["username"]
+            writer.writerow(json_dict_result)
+
+
+def _process_output(result: Dict, output: str = None) -> None:
+    """
+    Presents the gql response. The result would be printed or save to
+    output file with indentation.
+
+    Parameters
+    ----------
+    result: Dict
+        gql response.
+    output: str
+        output file (Default value = None).
+    """
+    if output:
+        with open(output, "w", encoding="utf-8") as file:
+            json.dump(result, file, indent=4, sort_keys=True)
+            click.echo(f"The result has written to the output file: {output}")
+    else:
+        # print with indentation
+        click.echo(json.dumps(result, indent=4, sort_keys=True))
